@@ -71,6 +71,9 @@
 #define MIN(a,b) ((a) < (b) ? (a) : (b))
 #endif
 
+#define POINTER_TO_INT(pointer) (*((int*)&(pointer)))
+#define INT_TO_POINTER(integer) (reinterpret_cast<void *>(integer))
+
 // -------------------------------------------------------
 // file interfaces
 // -------------------------------------------------------
@@ -85,6 +88,7 @@ public:
 public:
 
   fhandle(void) : f(NULL) {};
+  fhandle(FILE *f_in) : f(f_in) {};
 
   void operator=(void *f_)
   {
@@ -128,7 +132,7 @@ int       file_load_text(FHANDLE f, char * p_mem, t_off max_lenght, t_off start_
 
 void *    file_load(const char *p_dir, const char *p_file, t_off *p_lenght, t_off start_address = 0, bool safe = TRUE);
 
-bool      file_save(const char *p_dir, const char *p_file, void *p_buffer, t_off lenght);
+bool      file_save(const char *p_dir, const char *p_file, void *p_buffer, t_off lenght, const char *p_mode = "wb");
 
 bool      file_exists(const char *p_dir, const char *p_file);
 
@@ -136,17 +140,13 @@ int       file_size_get(const char * p_dir, const char * p_file);
 int       file_size_get(FHANDLE f);
 
 bool      file_copy(const char *p_src, const char *p_src_dir, const char *p_dest, const char *p_dest_dir, bool safe = TRUE);
+bool      file_copy(FHANDLE f_in, FHANDLE f_out, int len = 0);
 
 void      print_errno(bool new_line = FALSE);
 
 bool      dir_create(const char *p_dir);
 char   *  dir_home_get(char *p_dir, int max);
 
-// Don't use standart I/O
-#define fopen(a,b)
-#define fclose(a)
-#define FILE
-
 #define DEFAULT_DIR_MASK   0755
 #define DEFAULT_FILE_MASK  0644
 
@@ -360,12 +360,30 @@ public:
 } DIR_LIST;
 
 bool get_fullscreen(const char *p_ini_file);
+bool set_fullscreen(const char *p_ini_file, bool state);
+
+bool get_doublesize(const char *p_ini_file);
+bool set_doublesize(const char *p_ini_file, bool state);
+
+bool get_doublesize_question(const char *p_ini_file);
+bool set_doublesize_question(const char *p_ini_file, bool state);
+
 int  get_colors(const char *p_ini_file, int default_color_depth);
 
 // -------------------------------------------------------
 // the rest
 // -------------------------------------------------------
 
+inline char * get_tail(char * p_str)
+{
+  char *p_act = p_str, *p_last = NULL;
+  while((p_act = strchr(p_act, '.'))) {
+    p_last = p_act;
+    p_act++;
+  }  
+  return (p_last ? p_str : NULL);
+}
+
 inline char * change_tail(char * p_str, const char * p_end)
 {
   char *p_act = p_str, *p_last = NULL;
@@ -378,4 +396,31 @@ inline char * change_tail(char * p_str, const char * p_end)
   return (p_end ? (char *) strcat(p_str, p_end) : p_str);
 }
 
+#ifdef LINUX
+char * itoa(int base, char *buf, int d);
+#endif
+
+typedef struct _DIRECTORY_ENTRY {
+
+  char name[MAX_FILENAME];
+
+} DIRECTORY_ENTRY;
+
+int file_list_get(const char *p_dir, const char *p_mask, DIRECTORY_ENTRY **p_list);
+
+void  user_directory_create(void);
+
+/* Data loading
+*/
+bool  graphics_game_load(DIR_LIST *p_dir);
+void  graphics_game_free(void);
+
+bool  graphics_menu_load(DIR_LIST *p_dir);
+void  graphics_menu_free(void);
+
+bool  graphics_logos_load(DIR_LIST *p_dir);
+void  graphics_logos_free(void);
+
+void  graphics_generate(void);
+
 #endif // __UTILS_H__
